@@ -2,6 +2,8 @@
 import math
 from datetime import datetime, timedelta
 
+from boto.exception import DynamoDBResponseError
+
 import dynamodb
 from dynamic_dynamodb.log_handler import LOGGER as logger
 from cloudwatch import CLOUDWATCH_CONNECTION as cloudwatch_connection
@@ -92,10 +94,10 @@ def get_consumed_read_units_percent(table_name, time_frame=300):
     else:
         consumed_read_units = 0
 
-    consumed_read_units_percent = int(math.ceil(
-            float(consumed_read_units) / \
-            float(get_provisioned_read_units(table_name)) * \
-            100))
+    consumed_read_units_percent = int(
+        math.ceil(
+            float(consumed_read_units) /
+            float(get_provisioned_read_units(table_name)) * 100))
 
     logger.info('{0} - Consumed read units: {1:d}%'.format(
         table_name, consumed_read_units_percent))
@@ -127,10 +129,10 @@ def get_consumed_write_units_percent(table_name, time_frame=300):
     else:
         consumed_write_units = 0
 
-    consumed_write_units_percent = int(math.ceil(
-            float(consumed_write_units) / \
-            float(get_provisioned_write_units(table_name)) * \
-            100))
+    consumed_write_units_percent = int(
+        math.ceil(
+            float(consumed_write_units) /
+            float(get_provisioned_write_units(table_name)) * 100))
 
     logger.info('{0} - Consumed write units: {1:d}%'.format(
         table_name, consumed_write_units_percent))
@@ -144,7 +146,12 @@ def get_provisioned_read_units(table_name):
     :param table_name: Name of the DynamoDB table
     :returns: int -- Number of read units
     """
-    table = dynamodb.get_table(table_name)
+    try:
+        table = dynamodb.get_table(table_name)
+    except DynamoDBResponseError:
+        # Return if the table does not exist
+        return None
+
     logger.debug('{0} - Provisioned read units: {1:d}'.format(
         table_name, table.read_units))
     return int(table.read_units)
@@ -157,7 +164,12 @@ def get_provisioned_write_units(table_name):
     :param table_name: Name of the DynamoDB table
     :returns: int -- Number of write units
     """
-    table = dynamodb.get_table(table_name)
+    try:
+        table = dynamodb.get_table(table_name)
+    except DynamoDBResponseError:
+        # Return if the table does not exist
+        return None
+
     logger.debug('{0} - Provisioned write units: {1:d}'.format(
         table_name, table.write_units))
     return int(table.write_units)
